@@ -46,12 +46,14 @@
     doric-light
     doric-marble
     doric-oak
+    doric-siren
     doric-wind)
   "Light themes.")
 
 (defconst doric-themes-dark-themes
   '(doric-dark
     doric-fire
+    doric-mermaid
     doric-obsidian
     doric-pine
     doric-plum
@@ -1366,9 +1368,7 @@ default to a generic text that mentions the BACKGROUND-MODE."
               `(separator-line ((t :underline ,border)))
               `(scroll-bar ((t :background ,bg-main :foreground ,border)))
               `(fill-column-indicator ((t :foreground ,bg-shadow-intense)))
-              `(minibuffer-nonselected
-                ((((supports :strike-through t)) :strike-through t)
-                 (t :inverse-video t)))
+              `(minibuffer-nonselected ((t :inverse-video t)))
               `(tooltip ((t :background ,bg-accent :foreground ,fg-accent)))
               `(tty-menu-disabled-face ((t :background ,bg-accent :foreground ,fg-shadow-subtle)))
               `(tty-menu-enabled-face ((t :background ,bg-accent :foreground ,fg-main)))
